==> imask-6.0.3.jar: META-INF/resources/webjars/imask/6.0.3/esm/polyfills.js <==
var $ = require('../internals/export');

var assign = require('../internals/object-assign'); // `Object.assign` method
// https://tc39.github.io/ecma262/#sec-object.assign


$({
  target: 'Object',
  stat: true,
  forced: Object.assign !== assign
}, {
  assign: assign
});

var $$1 = require('../internals/export');

var $padEnd = require('../internals/string-pad').end;

var WEBKIT_BUG = require('../internals/string-pad-webkit-bug'); // `String.prototype.padEnd` method
// https://tc39.github.io/ecma262/#sec-string.prototype.padend


$$1({
  target: 'String',
  proto: true,
  forced: WEBKIT_BUG
}, {
  padEnd: function padEnd(maxLength
  /* , fillString = ' ' */
  ) {
    return $padEnd(this, maxLength, arguments.length > 1 ? arguments[1] : undefined);
  }
});

var $$2 = require('../internals/export');

var $padStart = require('../internals/string-pad').start;

var WEBKIT_BUG$1 = require('../internals/string-pad-webkit-bug'); // `String.prototype.padStart` method
// https://tc39.github.io/ecma262/#sec-string.prototype.padstart


$$2({
  target: 'String',
  proto: true,
  forced: WEBKIT_BUG$1
}, {
  padStart: function padStart(maxLength
  /* , fillString = ' ' */
  ) {
    return $padStart(this, maxLength, arguments.length > 1 ? arguments[1] : undefined);
  }
});

var $$3 = require('../internals/export');

var repeat = require('../internals/string-repeat'); // `String.prototype.repeat` method
// https://tc39.github.io/ecma262/#sec-string.prototype.repeat


$$3({
  target: 'String',
  proto: true
}, {
  repeat: repeat
});

// TODO: Remove from `core-js@4`
require('./es.global-this');

==> imask-6.0.7.jar: META-INF/resources/webjars/imask/6.0.7/esm/polyfills.js <==
var $ = require('../internals/export');

var assign = require('../internals/object-assign'); // `Object.assign` method
// https://tc39.es/ecma262/#sec-object.assign


$({
  target: 'Object',
  stat: true,
  forced: Object.assign !== assign
}, {
  assign: assign
});

var $$1 = require('../internals/export');

var $padEnd = require('../internals/string-pad').end;

var WEBKIT_BUG = require('../internals/string-pad-webkit-bug'); // `String.prototype.padEnd` method
// https://tc39.es/ecma262/#sec-string.prototype.padend


$$1({
  target: 'String',
  proto: true,
  forced: WEBKIT_BUG
}, {
  padEnd: function padEnd(maxLength
  /* , fillString = ' ' */
  ) {
    return $padEnd(this, maxLength, arguments.length > 1 ? arguments[1] : undefined);
  }
});

var $$2 = require('../internals/export');

var $padStart = require('../internals/string-pad').start;

var WEBKIT_BUG$1 = require('../internals/string-pad-webkit-bug'); // `String.prototype.padStart` method
// https://tc39.es/ecma262/#sec-string.prototype.padstart


$$2({
  target: 'String',
  proto: true,
  forced: WEBKIT_BUG$1
}, {
  padStart: function padStart(maxLength
  /* , fillString = ' ' */
  ) {
    return $padStart(this, maxLength, arguments.length > 1 ? arguments[1] : undefined);
  }
});

var $$3 = require('../internals/export');

var repeat = require('../internals/string-repeat'); // `String.prototype.repeat` method
// https://tc39.es/ecma262/#sec-string.prototype.repeat


$$3({
  target: 'String',
  proto: true
}, {
  repeat: repeat
});

// TODO: Remove from `core-js@4`
require('./es.global-this');
